#
# spec file for package libass
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 5

Name:           libass
Version:        0.12.1
Release:        2.6.1
Summary:        Portable Library for SSA/ASS Subtitles Rendering
License:        ISC
Group:          System/Libraries
Url:            https://github.com/libass/libass
Source:         https://github.com/libass/libass/releases/download/%{version}/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2) >= 9.10.3
BuildRequires:  pkgconfig(fribidi) >= 0.19.0

%description
libass is a portable subtitle renderer for the ASS/SSA
 (Advanced Substation Alpha/Substation Alpha) subtitle
format. It is mostly compatible with VSFilter.

%package -n libass%{soname}
Summary:        Portable Library for SSA/ASS Subtitles Rendering
Group:          Development/Libraries/C and C++

%description -n libass%{soname}
libass is a portable subtitle renderer for the ASS/SSA
 (Advanced Substation Alpha/Substation Alpha) subtitle
format. It is mostly compatible with VSFilter.

%package devel
Summary:        Portable Library for SSA/ASS Subtitles Rendering
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libass%{soname} = %{version}
Requires:       pkgconfig(enca)
Requires:       pkgconfig(fontconfig)
Requires:       pkgconfig(freetype2) >= 9.10.3
Requires:       pkgconfig(fribidi) >= 0.19.0

%description devel
This package is needed if you want to develop / compile against libASS.

%prep
%setup -q

%build
%configure --disable-silent-rules \
	--disable-static
make %{?_smp_mflags}

%install
make DESTDIR='%{buildroot}' install
rm -f %{buildroot}%{_libdir}/*.la

%check
make check

%post -n libass%{soname} -p /sbin/ldconfig

%postun -n libass%{soname} -p /sbin/ldconfig

%files -n libass%{soname}
%defattr(-, root, root)
%{_libdir}/*.so.%{soname}*

%files devel
%defattr(-, root, root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Jan 30 2015 p.drouand@gmail.com
- Update to version 0.12.1 (bnc#921212)
  * Make ASS drawings with an extremely high number of control points work
    This change increases compatibility with VSFilter.
  * Bugfixes
  - Fix a crash when using newer harfbuzz versions (GH #155)
  - Load embedded memory fonts correctly
  - Large shadow offsets rendered incorrectly (GH #142)
  - Fix incorrect closing of last drawing contour
  - Fix issues with undefined behavior in shifts
  - Lots of of malloc() error checking
- Update home and download source Url to new project home
- Add baselibs.conf in sources list for Factory
* Sun Oct  5 2014 olaf@aepfle.de
- add versioned Requires to devel pkg, enca is required by pkgconfig
* Thu Oct 17 2013 tchvatal@suse.com
- Version bup to 0.10.2
  * API additions and some ABI changes, bumped SONAME
  * Expose header field for VSFilter color mangling (GC #87)
  * Add functions for explicit scaling hints (GC #6)
  * Add 'type' field to ASS_Image (GC #31)
  * Workaround Freetype's font size grid-fitting where appropriate
  * Apply blur to both glyph and border when using opaque box
  * Parser bugfixes
  * Parse angles in style as number
  * Fix fallback event formats
  * Make closing ')' optional for some tags
  * Fix crazy VSFilter behaviour for \move (GC #90)
  * Make \r fall back to line style (GC #104)
  * Parse style name like VSFilter
  * Ignore junk in nested \t tags
  * Make \clip tag arguments mandatory
  * Properly handle script and language in the HarfBuzz shaper
  * Allow ASS_Track and ASS_Renderer to have different ASS_Library
  * Fix stroking in some rare cases
  * Correctly handle @font advance (GC #94)
  * Fix ascent/descent for some fonts (GC #106)
  * Fix ass_step_sub to not require sorted events
  * Fix blur scaling
  * Don't mutate input strings (GC #88)
  * Remove/change some error messages
  * Fix various small memory leaks
* Tue Oct 23 2012 reddwarf@opensuse.org
- Update to version 0.10.1
  * Fix letter spacing
  * Add \rSTYLENAME syntax support (GC #43)
  * Fix border generation and border style reset (GC #56)
  * Fix various issues with bug-for-bug compatibility of
    transformations (\fax, \fay, etc.) to VSFilter (GC #46, GC #42)
  * Fix drawing parsing (GC #47)
  * Various fixes to shaper (GC #54, GC #55, GC#59)
  * Fix change detection
  * Add ass_set_line_position API to set a vertical subtitle offset
  * Fix scaling of drawing baseline offset (\pbo) values
  * Fix skipping of zero-width characters for FriBiDi shaper
  * Use LTR text base direction by default, similar to VSFilter
* Sat Oct 29 2011 reddwarf@opensuse.org
- Update to version 0.10.0
  + Bidirectional layout and Arabic shaping via FriBidi (GC #13)
  + Add API for shaper configuration
  + Add support for `Language' Script Info property, this can be
    used for hinting the text language
  + Vertical layout improvements
  * Use `vert' and `vkna' OpenType features for vertical glyph
    variants
  * Position rotated glyphs onto baseline
  + Parse font encoding property for base text direction hinting
  + Refactor cache system
  + Use generic outlines in place of FreeType glyphs
  + Direct outline bitmap rendering
  + Fix whitespace trimming (GC #35)
  + Do not render border if there's no shadow or glyph (GC #29)
  + Adjust spacing after a italic to non-italic style change (GC #37)
  + Fix fade timing
  + Fix x positioning with borders (GC #27)
- Use pkgconfig() BuildRequires
- Parameterize the soname number
* Thu Jun 30 2011 dimstar@opensuse.org
- Update to version 0.9.12:
  + Switch to permissive (ISC) license
  + Support \fs+ and \fs- syntax for modifying font size
  + Fix word-wrapping
  + Improved charmap fallback matching
  + Handle a few more VSFilter quirks correctly
  + Add a sensible default style
  + Fix compilation against libpng 1.5
- Add xz BuildRequires, as the new tarballs are xz compressed
- Change License tag from GPLv2+ to ISC, as upstream changed to
  this license.
- Do not use source service, as Factory is moving away from it in
  favor of a different implementation to verify authenticity of
  tarballs. Consequently add a valid URL as Source.
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
- updated description to official description (fix for RPMLINT warning)
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- fix -devel package dependencies
* Fri Sep 10 2010 reddwarf@opensuse.org
- Update to version 0.9.11
  * Fix serious memory leaks
  * Reduce frame/drawing initialization overhead
  * Basic (incorrect, but working) support for @font vertical text layout
  * Fix multiple faces per font attachment
  * charmap selection fixes
  * Add ass_flush_events API function
  * Improve fullname font matching
  * Better PAR correction if text transforms are used
  * Calculate drawing bounding box like VSFilter
  * Performance improvements
  * Cache vector clip masks
  * Avoid unnecessary glyph copies
  * Various rendering fixes
  * Parse numbers in a locale-independent way
  * Remove support for freetype < 2.2.1, fontconfig < 2.4.1; this especially
  means libass will not extract fonts into the file system anymore
  * Disable script file size limit
  * Match fonts against the full name ("name for humans")
  * Reset clip mode after \iclip
  * Improve VSFilter compatibility
  * Update API documentation
  * A couple of smaller fixes and cleanups
  * Support \q override tag
  * Support wrap style 1 (i.e. wrap, but do not equalize line lengths)
  * Support border style 3 (opaque box)
  * Use the event bounding box (instead of vertical position and height) for
  collision detection
  * Embold glyphs if no bold variant is available, but was requested
  * Modify \fax to be similar to VSFilter
  * Trim spaces after line wrapping
  * Fix border/shadow overlap combining in some cases
  * Disable kerning by default.  Use "Kerning=yes" style override or
  "Kerning: yes" in [Script Info] to enable it
  * Slight bitmap handling optimizations
  * Various bugfixes
* Sat Sep 26 2009 cmorve69@yahoo.es
- Remove unneeded autoreconf
- Correct license tag
- Make build more verbose so checking tools can do its work
* Tue Aug 11 2009 sbrabec@suse.cz
- New SuSE package, version 0.9.7.
- Name and split according to shared library packaging policy.
* Sat Mar 21 2009 cmorve69@yahoo.es
- and now to the OBS
- update to 0.9.6
* Thu Sep 18 2008 detlef@links2linux.de
- initial build for PackMan to be compatible with vlc-repo
* Tue Aug 26 2008 dominique-rpm@leuenberger.net
- Initial package for version 0.9.5
